pub struct DIScope<'ctx> { /* private fields */ }
Any kind of debug information scope (i.e. visibility of a source code symbol). Scopes are
created by special DebugInfoBuilder methods (eg create_lexical_block) and can be turned
into a DIScope with the AsDIScope::as_debug_info_scope trait method.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.