Module llvm_plugin_inkwell::module
source · Expand description
A Module represets a single code compilation unit.
Structs
Iterate over all
FunctionValues in an llvm moduleRepresents a reference to an LLVM
Module.
The underlying module will be disposed when dropping this object.Enums
Defines the operational behavior for a module wide flag. This documenation comes directly
from the LLVM docs
This enum defines how to link a global variable or function in a module. The variant documenation is
mostly taken straight from LLVM’s own documentation except for some minor clarification.