pub struct AddressSpace(_);
Defines the address space in which a global will be inserted.

The default address space is zero. An address space can always be created from a u16:

inkwell::AddressSpace::from(1u16);

An Address space is a 24-bit number. To convert from a u32, use the TryFrom instance

inkwell::AddressSpace::try_from(42u32).expect("fits in 24-bit unsigned int");

Remarks

See also: https://llvm.org/doxygen/NVPTXBaseInfo_8h_source.html