Enum llvm_plugin_inkwell::types::StringRadix
source · pub enum StringRadix {
Binary,
Octal,
Decimal,
Hexadecimal,
Alphanumeric,
}Expand description
How to interpret a string or digits used to construct an integer constant.
Variants
Binary
Binary 0 or 1
Octal
Octal 0-7
Decimal
Decimal 0-9
Hexadecimal
Hexadecimal with upper or lowercase letters up to F.
Alphanumeric
Alphanumeric, 0-9 and all 26 letters in upper or lowercase.
Implementations
sourceimpl StringRadix
impl StringRadix
sourcepub fn matches_str(&self, slice: &str) -> bool
pub fn matches_str(&self, slice: &str) -> bool
Is the string valid for the given radix?