pub struct PointerType<'ctx> { /* private fields */ }
A PointerType is the type of a pointer constant or variable.

Implementations

Create PointerType from LLVMTypeRef

Safety

Undefined behavior, if referenced type isn’t pointer type

Gets the size of this PointerType. Value may vary depending on the target architecture.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_type_size = f32_ptr_type.size_of();

Gets the alignment of this PointerType. Value may vary depending on the target architecture.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_type_alignment = f32_ptr_type.get_alignment();

Creates a PointerType with this PointerType for its element type.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_ptr_type = f32_ptr_type.ptr_type(AddressSpace::default());

#[cfg(not(feature = "llvm15-0"))]
assert_eq!(f32_ptr_ptr_type.get_element_type().into_pointer_type(), f32_ptr_type);

Gets a reference to the Context this PointerType was created in.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());

assert_eq!(f32_ptr_type.get_context(), context);

Creates a FunctionType with this PointerType for its return type.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let fn_type = f32_ptr_type.fn_type(&[], false);

Creates an ArrayType with this PointerType for its element type.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_array_type = f32_ptr_type.array_type(3);

assert_eq!(f32_ptr_array_type.len(), 3);
assert_eq!(f32_ptr_array_type.get_element_type().into_pointer_type(), f32_ptr_type);

Gets the AddressSpace a PointerType was created with.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());

assert_eq!(f32_ptr_type.get_address_space(), AddressSpace::default());

Print the definition of a PointerType to LLVMString.

Creates a null PointerValue of this PointerType. It will be automatically assigned this PointerType’s Context.

Example
use inkwell::AddressSpace;
use inkwell::context::Context;

// Local Context
let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_null = f32_ptr_type.const_null();

assert!(f32_ptr_null.is_null());

Creates a constant null value of this PointerType. This is practically the same as calling const_null for this particular type and so this function may be removed in the future.

Example
use inkwell::AddressSpace;
use inkwell::context::Context;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_zero = f32_ptr_type.const_zero();

Creates an undefined instance of a PointerType.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_undef = f32_ptr_type.get_undef();

assert!(f32_ptr_undef.is_undef());

Creates a VectorType with this PointerType for its element type.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_vec_type = f32_ptr_type.vec_type(3);

assert_eq!(f32_ptr_vec_type.get_size(), 3);
assert_eq!(f32_ptr_vec_type.get_element_type().into_pointer_type(), f32_ptr_type);

Creates a constant ArrayValue.

Example
use inkwell::context::Context;
use inkwell::AddressSpace;

let context = Context::create();
let f32_type = context.f32_type();
let f32_ptr_type = f32_type.ptr_type(AddressSpace::default());
let f32_ptr_val = f32_ptr_type.const_null();
let f32_ptr_array = f32_ptr_type.const_array(&[f32_ptr_val, f32_ptr_val]);

assert!(f32_ptr_array.is_const());