pub struct VoidType<'ctx> { /* private fields */ }
A VoidType is a special type with no possible direct instances. It’s only useful as a function return type.

Implementations

Create VoidType from LLVMTypeRef

Safety

Undefined behavior, if referenced type isn’t void type

Gets whether or not this VoidType is sized or not. This may always be false and as such this function may be removed in the future.

Example
use inkwell::context::Context;

let context = Context::create();
let void_type = context.void_type();

assert!(void_type.is_sized());

Gets a reference to the Context this VoidType was created in.

Example
use inkwell::context::Context;

let context = Context::create();
let void_type = context.void_type();

assert_eq!(void_type.get_context(), context);

Creates a FunctionType with this VoidType for its return type. This means the function does not return.

Example
use inkwell::context::Context;

let context = Context::create();
let void_type = context.void_type();
let fn_type = void_type.fn_type(&[], false);

Print the definition of a VoidType to LLVMString.