pub struct ArrayValue<'ctx> { /* private fields */ }
An ArrayValue is a block of contiguous constants or variables.

Implementations

Get name of the ArrayValue. If the value is a constant, this will return an empty string.

Set name of the ArrayValue.

Gets the type of this ArrayValue.

Determines whether or not this value is null.

Determines whether or not this value is undefined.

Prints this ArrayValue to standard error.

Attempt to convert this ArrayValue to an InstructionValue, if possible.

Replaces all uses of this value with another value of the same type. If used incorrectly this may result in invalid IR.

Determines whether or not an ArrayValue is a constant.

Example
use inkwell::context::Context;

let context = Context::create();
let i64_type = context.i64_type();
let i64_val = i64_type.const_int(23, false);
let array_val = i64_type.const_array(&[i64_val]);

assert!(array_val.is_const());

Determines whether or not an ArrayValue is a constant string.

Determines whether or not an ArrayValue is a constant data array.

Returns a string constant if the ArrayValue is one, None otherwise.