pub struct VectorValue<'ctx> { /* private fields */ }

Implementations

Determines whether or not a VectorValue is a constant.

Example
use inkwell::context::Context;

let context = Context::create();
let i8_type = context.i8_type();
let i8_vec_type = i8_type.vec_type(3);
let i8_vec_zero = i8_vec_type.const_zero();

assert!(i8_vec_zero.is_const());

Gets the name of a VectorValue. If the value is a constant, this will return an empty string.

Set name of the VectorValue.

Creates a const string which may be null terminated.

Example
use inkwell::context::Context;

let context = Context::create();
let string = context.const_string(b"my_string", false);

assert!(string.is_const_string());