pub trait AggregateValue<'ctx>: BasicValue<'ctx> {
    fn as_aggregate_value_enum(&self) -> AggregateValueEnum<'ctx> { ... }
}
Represents an aggregate value, built on top of other values.

Provided Methods

Returns an enum containing a typed version of the AggregateValue.

Implementors