Struct llvm_plugin_inkwell::values::ArrayValue
source · pub struct ArrayValue<'ctx> { /* private fields */ }Expand description
An ArrayValue is a block of contiguous constants or variables.
Implementations
sourceimpl<'ctx> ArrayValue<'ctx>
impl<'ctx> ArrayValue<'ctx>
sourcepub fn get_name(&self) -> &CStr
pub fn get_name(&self) -> &CStr
Get name of the ArrayValue. If the value is a constant, this will
return an empty string.
sourcepub fn print_to_stderr(self)
pub fn print_to_stderr(self)
Prints this ArrayValue to standard error.
sourcepub fn as_instruction(self) -> Option<InstructionValue<'ctx>>
pub fn as_instruction(self) -> Option<InstructionValue<'ctx>>
Attempt to convert this ArrayValue to an InstructionValue, if possible.
sourcepub fn replace_all_uses_with(self, other: ArrayValue<'ctx>)
pub fn replace_all_uses_with(self, other: ArrayValue<'ctx>)
Replaces all uses of this value with another value of the same type. If used incorrectly this may result in invalid IR.
sourcepub fn is_const(self) -> bool
pub fn is_const(self) -> bool
Determines whether or not an ArrayValue is a constant.
Example
use inkwell::context::Context;
let context = Context::create();
let i64_type = context.i64_type();
let i64_val = i64_type.const_int(23, false);
let array_val = i64_type.const_array(&[i64_val]);
assert!(array_val.is_const());sourcepub fn is_const_string(self) -> bool
pub fn is_const_string(self) -> bool
Determines whether or not an ArrayValue is a constant string.
sourcepub fn is_const_data_array(self) -> bool
pub fn is_const_data_array(self) -> bool
Determines whether or not an ArrayValue is a constant data array.
sourcepub fn get_string_constant(&self) -> Option<&[u8]>
pub fn get_string_constant(&self) -> Option<&[u8]>
Returns a string constant if the ArrayValue is one, None otherwise.