Trait llvm_plugin_inkwell::values::AggregateValue
source · pub trait AggregateValue<'ctx>: BasicValue<'ctx> {
fn as_aggregate_value_enum(&self) -> AggregateValueEnum<'ctx> { ... }
}Expand description
Represents an aggregate value, built on top of other values.
Provided Methods
sourcefn as_aggregate_value_enum(&self) -> AggregateValueEnum<'ctx>
fn as_aggregate_value_enum(&self) -> AggregateValueEnum<'ctx>
Returns an enum containing a typed version of the AggregateValue.